/*
  $Id$
*/
#include "config.h"
#include "getopt.h"
#include "store.hpp"
#include "extract.hpp"

#include <string.h>
#include <iostream>
#include <map>
#include <string>
using namespace std;

// for getopt
const char *exec_name;
extern int optind;

static void print_usage() {
    cerr << "Usage: id3vorbis [OPTION]... [FILE]" << endl;
}

static void print_help() {
    cerr << "id3vorbis #" VERSION " stores ID3v2 tags from vorbis tag file," << endl;
    cerr << " and extracts ID3v2 tags to vorbis tag file." << endl;
    cerr << endl;
    print_usage();
    cerr << endl << "\
Options:\n\
  -h, --help               print this help.\n\
  -s FILE, --store=FILE    convert vorbis tag to ID3v2 and store it.\n\
                           you can use `-' as FILE, `-' means stdin.\n\
  -e FILE, --extract=FILE  extract ID3v2 and convert it to vorbis tag.\n\
                           you can use `-' as FILE, `-' means stdout.\n";
}

int main(int argc, char* argv[]) {
    static struct option long_options[] = {
	{"help", no_argument, NULL, 'h'},
	{"store", required_argument, NULL, 's'},
	{"extract", required_argument, NULL, 'e'},
	{0, 0, 0, 0}
    };

    // make exec_name without directory name
    exec_name = strchr(argv[0], '/');
    if (exec_name == NULL) {
	exec_name = argv[0];
    }
    else {
	exec_name++;
    }

    int c;
    map<string, string> opt;
    while ((c = getopt_long(argc, argv,
			    "hs:e:", long_options, (int*)NULL)) != -1) {
	switch (c) {
	case 'h':
	    print_help();
	    exit(0);
	    break;

	case 's':
	    opt["store"] = optarg;
	    break;

	case 'e':
	    opt["extract"] = optarg;
	    break;
	}
    }

    if (opt["store"] != "" && opt["extract"] != "") {
	cerr << "Error: you can't store and extract at the same time." << endl;
	cerr << endl;
	cerr << "Try `id3vorbis --help\'." << endl;
	exit(1);
    }

    if (opt["store"] == "" && opt["extract"] == "") {
	opt["extract"] = "-";
    }

    if (argc - optind == 0) {
	cerr << "Error: missing target file" << endl;
	cerr << endl;
	cerr << "Try `id3vorbis --help\'." << endl;
	exit(1);
    }

    if (opt["store"] != "") {
	store(argv[optind], opt["store"]);
    }
    else {
	extract(argv[optind], opt["extract"]);
    }

    return 0;
}
